@@ -1,2 +1,2 @@
 from __future__ import absolute_import
-from .sode import SODE
+from .sode import SODE, selection_type
